<?php
/*
 * timeline.js.php
 * Description: JavaScript for the SIMILE Timline Plugin
 * Plugin URI: http://www.freshlabs.de/journal/archives/2006/10/wordpress-plugin-simile-timeline/
 * Author: Tim Isenheim
 * 
	===========================================================================
	SIMILE Timeline for WordPress
	Copyright (C) 2006 Tim Isenheim
	
	This program is free software: you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation, either version 3 of the License, or
	(at your option) any later version.
	
	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.
	
	You should have received a copy of the GNU General Public License
	along with this program.  If not, see <http://www.gnu.org/licenses/>.
	===========================================================================
*/
include_once('../../../../wp-blog-header.php');
include_once('../inc/timeline-js.inc.php');

// Create JavaScript file header
header("Cache-Control: public");
header("Pragma: cache");

$offset = 60*60*24*10; // 10 days
header("Expires: ".gmdate("D, d M Y H:i:s",time() + $offset)." GMT");
header("Last-Modified: ".gmdate("D, d M Y H:i:s",filemtime(__FILE__))." GMT");
header("Content-Type: text/javascript; charset: UTF-8");


// Timeline orientation
if(get_option('stl_timeline_orientation')){
	$orientation = get_option('stl_timeline_orientation');	
} else $orientation = 0;

// get Timeline configurations
$stl_band_options = get_option('stl_timeline_band_options');
$stl_startdate_id = get_option('stl_timeline_startdate');

// default category and DOM-Id
$categories = '1';
$domid = "stl-mytimeline";

if(isset($_GET['cat'])){
	$categories = js_escape($_GET['cat']);
}else{
	$categories = get_option('stl_timelinecategories');
}

if(isset($_GET['id'])){
	$domid = js_escape($_GET['id']);
}


?>
/* WP SIMILE Timeline JavaScript configuration script
 * Plugin version: <?php echo $stl_timeline_plugin_version; ?>
 */
var tl;
function loadSimileTimeline() {
	
	if(document.getElementById("<?php echo $domid; ?>")){	
		
		// ### create custom theme
<?php stl_api_createTheme(''.
				'label_width=200&'.
				'bubble_width=320&'.
				'bubble_height=160&'.
				'
'); ?>


// ### duplicate theme and apply to lower band
var mytheme_second = Timeline.ClassicTheme.create();
mytheme_second = mytheme;


var eventSource = new Timeline.DefaultEventSource();

<?php
$datafile = STL_TIMELINE_DATA_FOLDER.'/timeline.xml.php';
#stl_api_createEventSourceArray($datafile, $categories);
// load data / event source
stl_api_createEventSource($datafile, $categories, 'eventSource');
?>



<?php
$stl_startdate = null;

// Evaluate the timeline start date (Where to focus on load)
switch($stl_startdate_id){
	case 3:		// In the middle of all events
		$a1= stl_getdate(stl_get_extreme_event_date('MAX','end', null, $categories));
		$b1= stl_getdate(stl_get_extreme_event_date('MIN','start', null, $categories));
		// calculate arithmetic middle date
		$amd = adodb_mktime(
			($a1['hour'] + $b1['hour'])/2,
			($a1['minute'] + $b1['minute'])/2,
			($a1['second'] + $b1['second'])/2,
			($a1['month'] + $b1['month'])/2,
			($a1['day'] + $b1['day'])/2,
			($a1['year'] + $b1['year'])/2
		);
		$stl_startdate = adodb_date('r', $amd);
		break;
	case 2:		// at end date of last post
		$stl_startdate = stl_get_extreme_event_date('MAX','end', 'r', $categories);
		break;
	case 1:		// at start date of first post
		$stl_startdate = stl_get_extreme_event_date('MIN','start', 'r', $categories);
		break;
	case 0: default:  // at current date
		$stl_startdate = date('r');
		break;
}


// convert value from checkbox value to boolean string (wtf?)
// TODO: This could be done on the options page...better save the true/false value
$stl_band_options['showbandlabels'][0] = $stl_band_options['showbandlabels'][0] == "on" ? "true" : "false";
$stl_band_options['showbandlabels'][1] = $stl_band_options['showbandlabels'][1] == "on" ? "true" : "false";
?>

var bandInfos = [
<?php
// Primary Timeline Band = 0
stl_api_createBandInfo(
			stl_api_createZone($stl_timeline_resolutions[$stl_band_options['units'][0]], adodb_date2('r', $stl_mindate), adodb_date2('r', $stl_maxdate), 1, 1),
			$stl_band_options['heights'][0],
			$stl_timeline_resolutions[$stl_band_options['units'][0]],
			$stl_band_options['intervals'][0],
			'mytheme',
			$stl_band_options['showbandlabels'][0],
			"eventSource",
			$stl_startdate,
			"0",
			false,
			false,
			get_option('stl_timeline_locale')
);

echo ',' . "\n";

// Seconday Timeline Band = 1
stl_api_createBandInfo(
			stl_api_createZone($stl_timeline_resolutions[$stl_band_options['units'][1]], adodb_date2('r', $stl_mindate), adodb_date2('r', $stl_maxdate), 1, 1),
			$stl_band_options['heights'][1],
			$stl_timeline_resolutions[$stl_band_options['units'][1]],
			$stl_band_options['intervals'][1],
			'mytheme_second',
			$stl_band_options['showbandlabels'][1],
			"eventSource",
			$stl_startdate,
			"0",
			'0.5',
			'0.3',
			get_option('stl_timeline_locale')
);
?>
];

/* This has to be done manually */
bandInfos[1].syncWith = 0;   // synchronize with primary band
bandInfos[1].highlight = true;   // highlight focused area
//bandInfos[1].eventPainter.setLayout(bandInfos[0].eventPainter.getLayout());
		
<?php // TODO: Create Span Highlight decorators here 
/* JavaScript example: 
for (var i = 0; i < bandInfos.length; i++) {
                bandInfos[i].decorators = [
                    new Timeline.SpanHighlightDecorator({
                        startDate:  "Fri Jul 22 2006 12:30:00 GMT-0600",
                        endDate:    "Fri Nov 22 2006 13:00:00 GMT-0600",
                        color:      "#FFC080",
                        opacity:    50,
                        startLabel: "started blogging",
                        endLabel:   "today",
                        theme:      mytheme
                    }),
                    new Timeline.PointHighlightDecorator({
                        date:       "Fri Nov 22 2006 14:38:00 GMT-0600",
                        color:      "#FFC080",
                        opacity:    50,
                        theme:      mytheme
                    }),
                    new Timeline.PointHighlightDecorator({
                        date:       "Sun Nov 24 2006 13:00:00 GMT-0600",
                        color:      "#FFC080",
                        opacity:    50,
                        theme:      mytheme
                    })
                ];
            }
*/
?>
<?php // create actual timeline object
	stl_api_createTimeLine($domid, 'bandInfos', $orientation);
	
	// change click event for timeline entries
	if(get_option('stl_timeline_linkhandling')){
		echo 'Timeline.DurationEventPainter.prototype._showBubble = function(x, y, evt) {';
		echo '	document.location.href=evt.getLink();';
		echo '}';
	}  
?>
  }else{ /* empty - do nothing when no timeline-frame is found */ }
}