<?php
/*
 * timeline.xml.php
 * Description: XML data for the SIMILE Timline Plugin. 
 * This file fetches the posts from the database and outputs them in the loop
 * Plugin URI: http://www.freshlabs.de/journal/archives/2006/10/wordpress-plugin-simile-timeline/
 * Author: Tim Isenheim
 * 
	===========================================================================
	SIMILE Timeline for WordPress
	Copyright (C) 2006 Tim Isenheim
	
	This program is free software: you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation, either version 3 of the License, or
	(at your option) any later version.
	
	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.
	
	You should have received a copy of the GNU General Public License
	along with this program.  If not, see <http://www.gnu.org/licenses/>.
	===========================================================================
*/
include_once('../../../../wp-blog-header.php');

/* =========================================================================
 * get post data
 * =========================================================================
 */
// get category IDs from Ajax post parameters
$cat = $_GET['cat']; 
// TODO: Sanitize query string. Allow numeric IDs and ',' only
$cat = js_escape($cat);

// RSS config
$rss_links = get_bookmarks("category=$cat");
// catch WordPress MU Installations
if(strstr($wp_version, 'wordpress-mu') === FALSE){
	require_once(ABSPATH . WPINC . '/rss-functions.php');
}else{
	require_once(ABSPATH . WPINC . '/rss.php');
}

// Get posts from the timeline categories
$poststatus = "publish";
if(get_option('stl_timeline_showfutureposts') == '1') $poststatus .= ",future";
query_posts("cat=$cat&post_status=$poststatus&showposts=-1");

/* =========================================================================
 * begin XML document
 * =========================================================================
 */
header('Content-type: text/xml; charset=UTF-8');
header("Pragma: no-cache");
echo '<?xml version="1.0" encoding="UTF-8"?'.'>' . "\n\r";
echo '<data>' . "\n\r";

/* =========================================================================
 * BEGIN the LOOP for post data ********************************************
 * =========================================================================
 */
while (have_posts()) : the_post();

	$stl_icon = get_post_meta($post->ID, 'stl-icon', true);
	$stl_image = get_post_meta($post->ID, 'stl-image', true);
	$stl_link = get_post_meta($post->ID, 'stl-link', true);
	$stl_tapeImage = get_post_meta($post->ID, 'stl-tapeImage', true);
	$stl_caption = get_post_meta($post->ID, 'stl-caption', true);
	$stl_classname = get_post_meta($post->ID, 'stl-classname', true);

	echo '<event ';
	/* =========================================================================
	 * time information
	 * =========================================================================
	 */
	// use event start date if explicitly set
	if($post->stl_timeline_event_start != '0000-00-00 00:00:00' && $post->stl_timeline_event_start != null):
		echo 'start="' . adodb_date2('r', $post->stl_timeline_event_start)  .'"';
	// ...otherwise use the post publish date
	else:
		echo 'start="' . get_the_time('r') . '"';  // or get_the_time('D M Y H:i:s') . " GMT".date('O')
	endif;
	
	if($post->stl_timeline_event_latest_start != '0000-00-00 00:00:00' && $post->stl_timeline_event_latest_start != null)
		echo ' latestStart="' . adodb_date2('r', $post->stl_timeline_event_latest_start)  .'"';
	
	// event has a duration if the end date is set for the current post
	if($post->stl_timeline_event_end != '0000-00-00 00:00:00' && $post->stl_timeline_event_end != null):
		echo ' end="' . adodb_date2('r', $post->stl_timeline_event_end) .'"';
		// is there an earliestEnd?
		if($post->stl_timeline_event_earliest_end != '0000-00-00 00:00:00' && $post->stl_timeline_event_earliest_end != null){
			echo ' earliestEnd="' . adodb_date2('r', $post->stl_timeline_event_earliest_end) .'"';
			echo ' durationEvent="true"'; // in every case true, when earliestEnd AND end are set
		}
		else{
			echo ' durationEvent="true"'; // TODO: read from $post->stl_timeline_is_duration_event
		}
		
	endif;
	/* =========================================================================
	 * title information
	 * =========================================================================
	 */
	echo ' title="';
	the_title_rss();
	echo '"';
	/* =========================================================================
	 * link information
	 * =========================================================================
	 */
	if($stl_link != '') $titlelink = $stl_link;
	else $titlelink = get_permalink($post->ID);
	echo ' link="' . $titlelink . '"';
	/* =========================================================================
	 * category color
	 * =========================================================================
	 */
	$stl_term = stl_get_timeline_term_for_post($post->ID);

	echo ' color="'.$stl_term->color . '"';
	/* =========================================================================
	 * custom field values
	 * =========================================================================
	 */
	if($stl_icon != '') echo " icon=\"$stl_icon\"";
	if($stl_image != '') echo " image=\"$stl_image\"";
	if($stl_tapeImage != '') echo " tapeImage=\"$stl_tapeImage\"";
	if($stl_caption != '') echo " caption=\"$stl_caption\"";
	if($stl_classname != '') echo " classname=\"$stl_classname\"";
	echo ">\n\r";
	/* =========================================================================
	 * custom filtering for content. keep but encode html elements
	 * =========================================================================
	 */
	$the_content = $post->post_content;
	echo stl_timeline_html_filter($the_content);
	// =========================================================================
	echo '</event>';
	echo "\n\r";
endwhile;
/* =============================================================================
 * begin loop for RSS links ****************************************************
 * =============================================================================
 */
foreach($rss_links as $link){
	$feedContent = @fetch_rss($link->link_rss);
	$feedItems = $feedContent->items;
	$term = stl_get_term($link->term_id);
	if(!empty($feedItems)){
		foreach($feedItems as $feedItem){
			echo "<event";
			$pubdate = date('r');
			// catch multiple possible index names
			if(isset($feedItem['published']))
			{
				$pubdate = $feedItem['published'];
			}
			else if(isset($feedItem['pubdate']))
			{
				$pubdate = $feedItem['pubdate'];
			}
			echo " start=\"" . adodb_date2('r', strtotime($feedItem['published'])) . "\"";
			echo " title=\"" . stl_timeline_html_filter($feedItem['title']) . "\"";
			echo " link=\"" . $feedItem['link'] . "\"";
			echo " icon=\"" . $link->link_image . "\"";
			echo " color=\"" . $term->color . "\"";
			echo ">";
			echo stl_timeline_html_filter($feedItem['summary']) . "\n";
			echo "</event>" . "\n";
		}
	}
}
// =============================================================================
echo '</data>';
?>