<?php
/*
 * timeline-js.inc.php
 * Description: Timeline functions used to generate JavaScript
 * Plugin URI: http://www.freshlabs.de/journal/archives/2006/10/wordpress-plugin-simile-timeline/
 * Author: Pete Myers, Tim Isenheim
 * 
	===========================================================================
	SIMILE Timeline for WordPress
	Copyright (C) 2006 Tim Isenheim
	
	This program is free software: you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation, either version 3 of the License, or
	(at your option) any later version.
	
	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.
	
	You should have received a copy of the GNU General Public License
	along with this program.  If not, see <http://www.gnu.org/licenses/>.
	===========================================================================
*/

$stl_timeline_resolutions = array(
		1 => 'Timeline.DateTime.YEAR',
		2 => 'Timeline.DateTime.MONTH',
		3 => 'Timeline.DateTime.WEEK',		
		4 => 'Timeline.DateTime.DAY',
		5 => 'Timeline.DateTime.HOUR'
	);

/***********************************************************************
 * API FUNCTIONS
 ***********************************************************************/

/* ---------------------------------------------------------------------------------
 * stl_api_createTimeLine()
 * Create the actual Timeline object
 * ---------------------------------------------------------------------------------*/
function stl_api_createTimeLine($id, $bandInfos, $orientation) {
	echo 'tl = Timeline.create(document.getElementById("'.$id.'"), '.$bandInfos.', '.$orientation.');' . "\n";
}

/* ---------------------------------------------------------------------------------
 * stl_api_createEventSource()
 * Create and execute the Timeline request for data sources
 * ---------------------------------------------------------------------------------*/
function stl_api_createEventSource($datafile, $categories, $name) {
	echo 'Timeline.loadXML("'.$datafile.'?cat='.$categories.'",'."\n";
	echo '		function(xml, url) {'."\n";
	echo '			'.$name.'.loadXML(xml, url);'."\n";
	echo '});';
	echo "\n";
}

/* ---------------------------------------------------------------------------------
 * stl_api_createEventSourceArray()
 * Create a JavaScript array of Event sources to load from multiple sources
 * ---------------------------------------------------------------------------------*/
function stl_api_createEventSourceArray($datafile, $categories) {
	$numBands = count($categories);
	echo "var eventSources = new Array();\n";
	for ( $i=0; $i<=$numBands; $i+=1 ) {
		echo "var eventSource_".strval($i)." = new Timeline.DefaultEventSource();\n";
		stl_api_createEventSource($datafile, $categories[$i], "eventSource_".strval($i));
		echo "eventSources.push(eventSource_".strval($i).");\n";
	}
}

/* ---------------------------------------------------------------------------------
 * stl_api_createZone()
 * Build zone parameters
 * ---------------------------------------------------------------------------------*/
function stl_api_createZone(
			$unit,
			$startTime,
			$endTime,
			$magnify="1",
			$multiple="1"
) {
	$jvcode = '{'."\n";
	$jvcode .= '	start:	"'.$startTime.'",'."\n";
	$jvcode .= '	end:	"'.$endTime.'",'."\n";
	$jvcode .= '	magnify:	'.$magnify.','."\n";
	$jvcode .= '	unit:		'.$unit.','."\n";
	$jvcode .= '	multiple:	'.$multiple."\n";
	$jvcode .= '}';
	return $jvcode;
}

/* ---------------------------------------------------------------------------------
 * stl_api_createBandInfo()
 * --------------------------------------------------------------------------------*/
function stl_api_createBandInfo(
			$zones,
			$width,
			$intervalUnit,
			$intervalPixels,
			$theme,
			$showEventText="true",
			$eventSource="eventSource",
			$date = null,
			$timeZone="0",
			$trackGap="",
			$trackHeight="",
			$locale=''
) {
	if($date==null) $date = date('r'); // use current date as focus if none is set
	echo 'Timeline.createHotZoneBandInfo({';
	echo '	zones:['.$zones.'],'."\n";
	echo '	width:          "'.$width.'",'."\n";
	echo '	intervalUnit:   '.$intervalUnit.','."\n";
	echo '	intervalPixels: '.$intervalPixels.','."\n";
	echo '	eventSource:    '.$eventSource.','."\n";
	echo '	date:           "'.$date.'",'."\n";
	echo '	timeZone:	'.$timeZone.','."\n";
	if ($trackGap){		echo '	trackGap:	'.$trackGap.','."\n";	}
	if ($trackHeight){	echo '	trackHeight:	'.$trackHeight.','."\n";}
	echo '	showText:	'.$showEventText.','."\n";
	echo '	theme:		'.$theme.','."\n";
	// TODO: layout or overview? implement options in admin interface?
	#echo '	layout:		"overview",'."\n";
	echo '	overview:	'.($showEventText=='false'?'true':'false').','."\n";
	echo '	locale:		"'.$locale.'"'."\n";
	echo '})';
}

/* ---------------------------------------------------------------------------------
 * stl_api_createTheme()
 * --------------------------------------------------------------------------------*/
function stl_api_createTheme($args='') {
	$defaults = array(
		'name' => 'mytheme',
		'instant_icon' => 'Timeline.urlPrefix + "images/gray-circle.png"',
		'label_width' => '200',
		'bubble_width' => '320',
		'bubble_height' => '160',
		'firstDayOfWeek' => '0',
		'highlightOpacity' => '50',
		'line_show' => 'true',
		'line_opacity' => '25',
		'weekend_opacity' => '30',
		'hAlign' => "Bottom",
		'vAlign' => "Right",
		'track_offset' => '0.5',
		'track_height' => '1.5',
		'track_gap' => '0.5',
		'instant_impreciseOpacity' => '20',
		'instant_showLineForNoText' => 'true',
		'duration_opacity' => '100',
		'duration_impreciseOpacity' => '20',
		'highlightColors' => '["#FFFF00","#FFC000","#FF0000","#0000FF"]',
		'timeline_ether_marker_bottom' => "timeline-ether-marker-bottom",
		'timeline_ether_marker_bottom_emphasized' => "timeline-ether-marker-bottom-emphasized",
		'timeline_ether_marker_top' => "timeline-ether-marker-top",
		'timeline_ether_marker_top_emphasized' => "timeline-ether-marker-top-emphasized",
		'timeline_ether_marker_right' => "timeline-ether-marker-right",
		'timeline_ether_marker_right_emphasized' => "timeline-ether-marker-right-emphasized",
		'timeline_ether_marker_left' => "timeline-ether-marker-left",
		'timeline_ether_marker_left_emphasized' => "timeline-ether-marker-left-emphasized",
		'timeline_event_bubble_title' => "timeline-event-bubble-title",
		'timeline_event_bubble_body' => "timeline-event-bubble-body",
		'timeline_event_bubble_image' => "timeline-event-bubble-image",
		'timeline_event_bubble_wiki' => "timeline-event-bubble-wiki",
		'timeline_event_bubble_time' => "timeline-event-bubble-time"
	);

	$r = wp_parse_args( $args, $defaults );
	extract( $r, EXTR_SKIP );
	
	echo 'var '.$name.' = Timeline.ClassicTheme.create();'."\n";

	echo $name.'.firstDayOfWeek = '.$firstDayOfWeek.';'."\n";

	echo $name.'.ether.highlightOpacity = '.$highlightOpacity.';'."\n";
	echo $name.'.ether.interval.line.show = '.$line_show.';'."\n";
	echo $name.'.ether.interval.line.color = "'.$line_color.'";'."\n";
	echo $name.'.ether.interval.line.opacity = '.$line_opacity.';'."\n";
	echo $name.'.ether.interval.weekend.color = "'.$weekend_color.'";'."\n";
	echo $name.'.ether.interval.weekend.opacity = '.$weekend_opacity.';'."\n";
	echo $name.'.ether.interval.marker.hAlign = "'.$hAlign.'";'."\n";
	echo $name.'.ether.interval.marker.hBottomStyler = function(elmt) {'."\n";
	echo '				elmt.className = "'.$timeline_ether_marker_bottom.'";'."\n";
	echo '};'."\n";
	echo $name.'.ether.interval.marker.hBottomEmphasizedStyler = function(elmt) {'."\n";
	echo '				elmt.className = "'.$timeline_ether_marker_bottom_emphasized.'";'."\n";
	echo '};'."\n";
	echo $name.'.ether.interval.marker.hTopStyler = function(elmt) {'."\n";
	echo '				elmt.className = "'.$timeline_ether_marker_top.'";'."\n";
	echo '};'."\n";
	echo $name.'.ether.interval.marker.hTopEmphasizedStyler = function(elmt) {'."\n";
	echo '				elmt.className = "'.$timeline_ether_marker_top_emphasized.'";'."\n";
	echo '};'."\n";
	echo $name.'.ether.interval.marker.vAlign = "'.$vAlign.'";'."\n";
	echo $name.'.ether.interval.marker.vRightStyler = function(elmt) {'."\n";
	echo '				elmt.className = "'.$timeline_ether_marker_right.'";'."\n";
	echo '};'."\n";
	echo $name.'.ether.interval.marker.vRightEmphasizedStyler = function(elmt) {'."\n";
	echo '				elmt.className = "'.$timeline_ether_marker_right_emphasized.'";'."\n";
	echo '};'."\n";
	echo $name.'.ether.interval.marker.vLeftStyler = function(elmt) {'."\n";
	echo '				elmt.className = "'.$timeline_ether_marker_left.'";'."\n";
	echo '};'."\n";
	echo $name.'.ether.interval.marker.vLeftEmphasizedStyler = function(elmt) {'."\n";
	echo '				elmt.className = "'.$timeline_ether_marker_left_emphasized.'";'."\n";
	echo '};'."\n";

	echo $name.'.event.track.offset = '.$track_offset.';'."\n";
	echo $name.'.event.track.height = '.$track_height.';'."\n";
	echo $name.'.event.track.gap = '.$track_gap.';'."\n";
	echo $name.'.event.instant.icon = '.$instant_icon.';'."\n";
	echo $name.'.event.instant.impreciseOpacity = '.$instant_impreciseOpacity.';'."\n";
	echo $name.'.event.instant.showLineForNoText = '.$instant_showLineForNoText.';'."\n";
	echo $name.'.event.duration.opacity = '.$duration_opacity.';'."\n";
	echo $name.'.event.duration.impreciseOpacity = '.$duration_impreciseOpacity.';'."\n";
	echo $name.'.event.label.width = '.$label_width.';'."\n";
	echo $name.'.event.highlightColors = '.$highlightColors.';'."\n";
	echo $name.'.event.bubble.width = '.$bubble_width.';'."\n";
	echo $name.'.event.bubble.height = '.$bubble_height.';'."\n";
	echo $name.'.event.bubble.titleStyler = function(elmt) {'."\n";
	echo '				elmt.className = "'.$timeline_event_bubble_title.'";'."\n";
	echo '};'."\n";
	echo $name.'.event.bubble.bodyStyler = function(elmt) {'."\n";
	echo '				elmt.className = "'.$timeline_event_bubble_body.'";'."\n";
	echo '};'."\n";
	echo $name.'.event.bubble.imageStyler = function(elmt) {'."\n";
	echo '				elmt.className = "'.$timeline_event_bubble_image.'";'."\n";
	echo '};'."\n";
	echo $name.'.event.bubble.wikiStyler = function(elmt) {'."\n";
	echo '				elmt.className = "'.$timeline_event_bubble_wiki.'";'."\n";
	echo '};'."\n";
	echo $name.'.event.bubble.timeStyler = function(elmt) {'."\n";
	echo '				elmt.className = "'.$timeline_event_bubble_time.'";'."\n";
	echo '};'."\n";
}
// EOF
?>